#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.10.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.10.0-JppM9csVct670WY5F79WQ7
key:                  ghc-syntax-highlighter-0.0.10.0-JppM9csVct670WY5F79WQ7
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  fc9751e183c4f806830eee45ce6a619f
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/ghc-syntax-highlighter-0.0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.10.0-JppM9csVct670WY5F79WQ7
depends:
    base-4.18.2.1 ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

